leaftools.fuse_leaves_in_tie_chain_by_immediate_parent
======================================================

.. autofunction:: abjad.tools.leaftools.fuse_leaves_in_tie_chain_by_immediate_parent.fuse_leaves_in_tie_chain_by_immediate_parent
   :noindex:
